==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/mn.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Дүрмийн тайлбар товч",
    "Add rule" : "Дүрэм нэмэх",
    "Reset" : "тохируулах",
    "Save" : "хадгалах",
    "Saving…" : "хадгалж байна",
    "Saved" : "Хадгалсан",
    "Saving failed:" : "Хадгалалт бүтэлгүйтэв:",
    "Add rule group" : "Бүлэгт дүрэм нэмэх",
    "File MIME type" : "Файлын MIME төрөл",
    "is" : "бол",
    "is not" : "биш",
    "matches" : "тохируулах",
    "does not match" : "таарахгүй байна",
    "Example: {placeholder}" : "Жишээ нь: {байрлал}",
    "File size (upload)" : "файлын хэмжээ (байршуулсан)",
    "less" : "бага",
    "less or equals" : "Бага буюу тэнцүү",
    "greater or equals" : "Их буюу тэнцүү",
    "greater" : "илүү их",
    "File system tag" : "Файлын системийн хаяг",
    "is tagged with" : "Тэмдэглэгдсэн байна",
    "is not tagged with" : "тэмдэглэгдээгүй байна",
    "Select tag…" : "хаяг сонгоно уу",
    "Request remote address" : "алсын хаяг авах хүсэлт",
    "matches IPv4" : "IPv4 тохируулах ",
    "does not match IPv4" : "IPv4 тохируулагдаагүй байна",
    "matches IPv6" : "IPv6 тохируулах ",
    "does not match IPv6" : "IPv6 тохируулагдаанүй байна",
    "Request time" : "Хүсэлт гаргах хугацаа",
    "between" : "хооронд",
    "not between" : "Хооронд биш",
    "Start" : "эхлэх",
    "End" : "дуусгах",
    "Select timezone…" : "Timezone сонго ...",
    "Request URL" : "URL-н хүсэлт",
    "Predefined URLs" : "Урьдчилан тодорхойлсон URLууд",
    "Files WebDAV" : "WebDAV файлууд",
    "Android client" : "Android хэрэглэгч",
    "iOS client" : "iOS үйлчлүүлэгч",
    "Desktop client" : "захиалагчийн дэлгэц",
    "User group membership" : "хэрэглэгчийн бүлгийн гишүүнчлэл",
    "is member of" : "-ын гишүүн ",
    "is not member of" : "-ын гишүүн биш",
    "The given operator is invalid" : "Өгөгдсөн оператор буруу байна",
    "The given regular expression is invalid" : "Өгөгдсөн тогтмол илэрхийлэл буруу байна",
    "The given file size is invalid" : "Өгөгдсөн файлын хэмжээ буруу байна",
    "The given tag id is invalid" : "Өгөгдсөн шошго  буруу байна",
    "The given IP range is invalid" : "Өгөгдсөн IP хязгаар буруу байна",
    "The given IP range is not valid for IPv4" : "Өгөгдсөн IP хүрээ , IPv4-д хүчингүй байна",
    "The given IP range is not valid for IPv6" : "Өгөгдсөн IP хүрээ IPv6-д хүчингүй байна",
    "The given time span is invalid" : "Өгөгдсөн цаг хугацаа буруу байна",
    "The given start time is invalid" : " эхлэх цаг буруу байна",
    "The given end time is invalid" : "төгсөглийн хугацаа буруу байна",
    "The given group does not exist" : "Өгөгдсөн бүлэг байхгүй байна",
    "Check %s is invalid or does not exist" : "%sшалгахад хүчингүй эсвэл байхгүй байна",
    "Operation #%s does not exist" : "%s үйл ажиллагаа байхгүй",
    "Workflow" : "ажлын үйл явц",
    "Open documentation" : "Нээлттэй баримт бичиг",
    "Loading…" : "уншиж байна"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/mn.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Дүрмийн тайлбар товч",
    "Add rule" : "Дүрэм нэмэх",
    "Reset" : "тохируулах",
    "Save" : "хадгалах",
    "Saving…" : "хадгалж байна",
    "Saved" : "Хадгалсан",
    "Saving failed:" : "Хадгалалт бүтэлгүйтэв:",
    "Add rule group" : "Бүлэгт дүрэм нэмэх",
    "File MIME type" : "Файлын MIME төрөл",
    "is" : "бол",
    "is not" : "биш",
    "matches" : "тохируулах",
    "does not match" : "таарахгүй байна",
    "Example: {placeholder}" : "Жишээ нь: {байрлал}",
    "File size (upload)" : "файлын хэмжээ (байршуулсан)",
    "less" : "бага",
    "less or equals" : "Бага буюу тэнцүү",
    "greater or equals" : "Их буюу тэнцүү",
    "greater" : "илүү их",
    "File system tag" : "Файлын системийн хаяг",
    "is tagged with" : "Тэмдэглэгдсэн байна",
    "is not tagged with" : "тэмдэглэгдээгүй байна",
    "Select tag…" : "хаяг сонгоно уу",
    "Request remote address" : "алсын хаяг авах хүсэлт",
    "matches IPv4" : "IPv4 тохируулах ",
    "does not match IPv4" : "IPv4 тохируулагдаагүй байна",
    "matches IPv6" : "IPv6 тохируулах ",
    "does not match IPv6" : "IPv6 тохируулагдаанүй байна",
    "Request time" : "Хүсэлт гаргах хугацаа",
    "between" : "хооронд",
    "not between" : "Хооронд биш",
    "Start" : "эхлэх",
    "End" : "дуусгах",
    "Select timezone…" : "Timezone сонго ...",
    "Request URL" : "URL-н хүсэлт",
    "Predefined URLs" : "Урьдчилан тодорхойлсон URLууд",
    "Files WebDAV" : "WebDAV файлууд",
    "Android client" : "Android хэрэглэгч",
    "iOS client" : "iOS үйлчлүүлэгч",
    "Desktop client" : "захиалагчийн дэлгэц",
    "User group membership" : "хэрэглэгчийн бүлгийн гишүүнчлэл",
    "is member of" : "-ын гишүүн ",
    "is not member of" : "-ын гишүүн биш",
    "The given operator is invalid" : "Өгөгдсөн оператор буруу байна",
    "The given regular expression is invalid" : "Өгөгдсөн тогтмол илэрхийлэл буруу байна",
    "The given file size is invalid" : "Өгөгдсөн файлын хэмжээ буруу байна",
    "The given tag id is invalid" : "Өгөгдсөн шошго  буруу байна",
    "The given IP range is invalid" : "Өгөгдсөн IP хязгаар буруу байна",
    "The given IP range is not valid for IPv4" : "Өгөгдсөн IP хүрээ , IPv4-д хүчингүй байна",
    "The given IP range is not valid for IPv6" : "Өгөгдсөн IP хүрээ IPv6-д хүчингүй байна",
    "The given time span is invalid" : "Өгөгдсөн цаг хугацаа буруу байна",
    "The given start time is invalid" : " эхлэх цаг буруу байна",
    "The given end time is invalid" : "төгсөглийн хугацаа буруу байна",
    "The given group does not exist" : "Өгөгдсөн бүлэг байхгүй байна",
    "Check %s is invalid or does not exist" : "%sшалгахад хүчингүй эсвэл байхгүй байна",
    "Operation #%s does not exist" : "%s үйл ажиллагаа байхгүй",
    "Open documentation" : "Нээлттэй баримт бичиг",
    "Loading…" : "уншиж байна",
    "Workflow" : "ажлын үйл явц"
},
"nplurals=2; plural=(n != 1);");
